<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing of a Text field.
	 * 
	 * OPTIONAL
	 * $options["size"] - size of the form's text input field
	 * $options["maxlength"] - maximum length of text input field
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class Text extends FieldManager {
		/**
		 * Prepares this form field for display.
		 * 
		 * @param STRING $defaultValue The default value to show in this field
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function show($defaultValue, $enabled=true) {
			$options = $this->getOptions();
			
			$ret = '<input type="text" name="'.$this->getName().'" value="'.FieldManager::formPrep($defaultValue).'"';
			if(!empty($options["size"])) {
				$ret .= ' size="'.$options["size"].'"';
			}
			if(!empty($options["maxlength"])) {
				$ret .= ' maxlength="'.$options["maxlength"].'"';
			}
			if(!$enabled) {
				$ret .= ' readonly';
			}
			$ret .= '>';
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Processes this field and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param STRING $value Value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			$options = $this->getOptions();
			if(!empty($options["maxlength"])) {
				if(strlen($value) > $options["maxlength"]) {
					//HTML should enforce this - this should never occur.
					$this->error = "The provided value was longer than the maximum length allowed";
				}
			}
			return FieldManager::SQLPrep($value);
		}
	}
?>