<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing of a TextArea field.
	 * 
	 * $options["rows"] - Number of rows (lines) in this textarea
	 * $options["cols"] - Number of columns (characters per row) in this textarea
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class TextArea extends FieldManager {
		/**
		 * Prepares this form field for display.
		 * 
		 * @param STRING $defaultValue The default value to show in this field
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function show($defaultValue, $enabled=true) {
			$options = $this->getOptions();
			
			if(!is_array($options) || count($options) < 2) {
				$this->error = 'This textarea does not have a specified width and height.<br>
					If you are not the system administrator, please contact him/her about this error.';
				return "ERROR";
			}
			
			$defaultValue = str_replace('<br>', "\n", $defaultValue);
			$ret = '<textarea name="'.$this->getName().'" rows="'.$options["rows"].'" cols="'.$options["cols"].'"';
			if(!$enabled) {
				$ret .= ' readonly';
			}
			$ret .= '>'.FieldManager::formPrep($defaultValue).'</textarea>';
			
			$ret .= $this->getErrorText();
			return $ret;
		}
		
		/**
		 * Processes this field and returns formated data ready for insertion into a SQL database.
		 * 
		 * @param STRING $value Value to process
		 * @param INTEGER $mode The type of this form (one of the form type constants defined in the Form class)
		 * @return STRING Formatted string ready for insertion into a SQL database
		 */
		function process($value, $mode) {
			$value = str_replace('<br>', "\n", $value);
			return FieldManager::SQLPrep($value);
		}
	}
?>