<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	//include all of the standard filters
	require_once($path."OpenSiteAdmin/scripts/classes/Filters/SingleFilter.php");
	
	/**
	 * Defines an interface for creating filters to generate SQL WHERE clauses.
	 * 
	 * @abstract
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	interface Filter {
		/**
		 * Returns an HTML form for display a filter for a list.
		 * Note that filter forms must define multiple field values as an array of values.
		 * 
		 * @param OBJECT $SQL DatabaseManager object.
		 * @param ARRAY $filters Array of Filter objects to use to filter a SQL query to get data for this form.
		 * @param MIXED $data Optional data to use in this form.
		 * @return STRING HTML to display for the filter form.
		 * @abstract
		 */
		function getForm($SQL=null, $filters=null, $data=null);
		
		/**
		 * Returns a formatted MySQL WHERE clause.
		 * 
		 * @return STRING Formatted string for use in a MySQL query
		 * @abstract
		 */
		function getWhereClause();
		
		/**
		 * Returns whether or not this filter has a value to use to alter a database query.
		 * 
		 * @return STRING True if this field can create a meaningful where clause
		 * @abstract
		 */
		function isEmpty();
		
		/**
		 * Sets the default value for this filter. Intended for use with this filter's form.
		 * 
		 * @param MIXED $value The value or values to use for this filter's where clause
		 * @return VOID
		 * @abstract
		 */
		function setDefaultValue($value);
	}
?>