<?php
	/*
	 *	Copyright 2007 John Oren
	 *	
	 *	Licensed under the Apache License, Version 2.0 (the "License");
	 *	you may not use this file except in compliance with the License.
	 *	You may obtain a copy of the License at
	 *		http://www.apache.org/licenses/LICENSE-2.0
	 *	Unless required by applicable law or agreed to in writing, software
	 *	distributed under the License is distributed on an "AS IS" BASIS,
	 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 *	See the License for the specific language governing permissions and
	 *	limitations under the License.
	 */
	
	
	/**
	 * Handles display and processing for a single row form.
	 * 
	 * This form displays the fields for a single row in a verticla format.
	 * Field titles are shown to the left of each element with each field on it's
	 * own line. All titles and fields are left-aligned.
	 * This form type does not use the form's optional parameter.
	 * 
	 * @author John Oren
	 * @version 1.0 December 30, 2007
	 */
	class Form_Single extends Form {
		/**
		 * Displays this form's row fields in a vertical HTML form.
		 * 
		 * @param INTEGER $mode One of the mode constants defined in this class.
		 * @param ARRAY $data Array of form data in the following format:
		 *				$data[rowID][fieldName] = value
		 * @return VOID
		 */
		function displayForm($mode, $data) {
			print '<table>';
			foreach($this->rows[0]->getFields() as $field) {
				$title = $field->getTitle();
				$fieldName = $field->getFieldName();
				
				print '<tr>';
				print '<td>'.$title.'</td>';
				
				$value = $data[$this->rows[0]->getRowID()][$fieldName];
				if(count($value) == 1) {
					$value = $value[0];
				}
				if(count($value) == 0) {
					$value = null;
				}
				
				print '<td>'.$field->show($value, $mode != Form::DELETE).'</td>';
				print '</tr>';
			}
			print '</table>';
		}
	}
?>